#!/bin/sh -x
# set default output to the HDMI card on the videocard
# this particular X session runs on (useful for multiseat)
#
# GPLv2+ (c) 2019 Michael Shigorin <mike@altlinux.org>

# check altertor-multiseat
[ -f /usr/lib/alterator/backend3/multiseat -a ! -f /etc/alterator/multiseat/pulse ] && exit 0

exec >$HOME/.multipulse.log 2>&1

dnum="${DISPLAY##*:}"
log="/var/log/Xorg.${dnum%%.*}.log"
[ -f "$log" ] || exit 0

# card0
card="$(grep -m1 'Adding drm device' "$log" |
	sed -rn 's,^.*/dev/dri/(card[0-9]+).*$,\1,p')"
[ -n "$card" ] || exit 0

# /sys/devices/pci0000:00/0000:00:00.0/0000:01:08.0/0000:07:00.1
sysdev="$(realpath "/sys/class/drm/$card/device" | sed 's,0$,1,')"
[ -d "$sysdev/sound" ] || exit 0

# 0000:07:00.1
pciid="$(basename "$sysdev")"
# 0000_07_00.1
pcidev="${pciid//:/_}"
[ -n "$pcidev" ] || exit 0

# wait for pulseaudio to actually start (and leave useful log contents)
pactl info

# *sometimes* it might lack _this_ audiocard at this moment
# (observed when booting off HDD, not observed with SSD system)
n=1
while ! pactl set-default-sink "alsa_output.pci-$pcidev.hdmi-stereo"; do
	sleep $n
	pactl exit
	sleep 1
	pactl info
	pacmd set-card-profile alsa_card.pci-$pcidev output:hdmi-stereo
	n=$((n+1))
	[ "$n" -lt 16 ] || break
done

# input: Elbrus 801-PC's onboard soundcard
[ -d /sys/devices/pci0000:00/0000:00:00.0/0000:01:02.3/sound ] &&
	pactl set-default-source alsa_input.pci-0000_01_02.3.analog-stereo ||
	exit 0
